import { SkyQueryableComponentHarness } from '@skyux/core/testing';
import { ComponentHarness } from '@angular/cdk/testing';

/**
 * Harness for interacting with a flyout iterator component in tests.
 * @internal
 */
class SkyFlyoutIteratorHarness extends ComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-flyout-iterator'; }
    #getNextButton = this.locatorFor('.sky-flyout-iterator-next');
    #getPreviousButton = this.locatorFor('.sky-flyout-iterator-previous');
    /**
     * Clicks the next button.
     */
    async clickNextButton() {
        const button = await this.#getNextButton();
        if (await this.#buttonIsDisabled(button)) {
            throw new Error('Could not click the next iterator because it is disabled.');
        }
        await button.click();
    }
    /**
     * Clicks the previous button.
     */
    async clickPreviousButton() {
        const button = await this.#getPreviousButton();
        if (await this.#buttonIsDisabled(button)) {
            throw new Error('Could not click the previous iterator because it is disabled.');
        }
        await button.click();
    }
    async #buttonIsDisabled(button) {
        const disabled = await button.getAttribute('disabled');
        return disabled !== null;
    }
}

/**
 * Harness for interacting with a flyout component in tests.
 */
class SkyFlyoutHarness extends SkyQueryableComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-flyout'; }
    #getFlyout = this.locatorFor('.sky-flyout');
    /**
     * Clicks the flyout's next iterator button.
     */
    async clickNextIteratorButton() {
        const iterator = await this.#getIterator();
        await iterator.clickNextButton();
    }
    /**
     * Clicks the flyout's previous iterator button.
     */
    async clickPreviousIteratorButton() {
        const iterator = await this.#getIterator();
        await iterator.clickPreviousButton();
    }
    /**
     * Clicks the flyout's primary action button.
     */
    async clickPrimaryActionButton() {
        const primaryAction = await this.#getPrimaryAction();
        await primaryAction.click();
    }
    /**
     * Clicks the flyout's close button.
     */
    async closeFlyout() {
        const closeButton = await this.locatorFor('.sky-flyout-btn-close')();
        await closeButton.click();
    }
    /**
     * Gets the flyout's aria-describedby attribute.
     */
    async getAriaDescribedBy() {
        return await (await this.#getFlyout()).getAttribute('aria-describedby');
    }
    /**
     * Gets the flyout's aria-label attribute.
     */
    async getAriaLabel() {
        return await (await this.#getFlyout()).getAttribute('aria-label');
    }
    /**
     * Gets the flyout's aria-labelledby attribute.
     */
    async getAriaLabelledBy() {
        return await (await this.#getFlyout()).getAttribute('aria-labelledby');
    }
    /**
     * Gets the flyout's ARIA role.
     */
    async getAriaRole() {
        return await (await this.#getFlyout()).getAttribute('role');
    }
    /**
     * Gets the flyout's maximum width.
     */
    async getFlyoutMaxWidth() {
        const resizeHandle = await this.locatorFor('.sky-flyout-resize-handle')();
        const currentWidthAttr = (await resizeHandle.getAttribute('aria-valuemax'));
        return parseInt(currentWidthAttr);
    }
    /**
     * Gets the flyout's minimum width.
     */
    async getFlyoutMinWidth() {
        const resizeHandle = await this.locatorFor('.sky-flyout-resize-handle')();
        const currentWidthAttr = (await resizeHandle.getAttribute('aria-valuemin'));
        return parseInt(currentWidthAttr);
    }
    /**
     * Gets the flyout's current width.
     */
    async getFlyoutWidth() {
        const resizeHandle = await this.locatorFor('.sky-flyout-resize-handle')();
        const currentWidthAttr = (await resizeHandle.getAttribute('aria-valuenow'));
        return parseInt(currentWidthAttr);
    }
    /**
     * Gets the label for the flyout's permalink button.
     */
    async getPermalinkButtonLabel() {
        const permalink = await this.#getPermalink();
        return await permalink.text();
    }
    /**
     * Gets the route for the flyout's permalink button.
     */
    async getPermalinkButtonRoute() {
        const permalink = await this.#getPermalink();
        return await permalink.getAttribute('href');
    }
    /**
     * Gets the label for the flyout's primary action button.
     */
    async getPrimaryActionButtonLabel() {
        const primaryAction = await this.#getPrimaryAction();
        return await primaryAction.text();
    }
    async #getIterator() {
        const iterator = await this.locatorForOptional(SkyFlyoutIteratorHarness)();
        if (iterator === null) {
            throw new Error('Could not find iterator buttons.');
        }
        return iterator;
    }
    async #getPermalink() {
        const permalink = await this.locatorForOptional('.sky-flyout-btn-permalink')();
        if (permalink === null) {
            throw new Error('Could not find permalink button.');
        }
        return permalink;
    }
    async #getPrimaryAction() {
        const primaryAction = await this.locatorForOptional('.sky-flyout-btn-primary-action')();
        if (primaryAction === null) {
            throw new Error('Could not find primary action button.');
        }
        return primaryAction;
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { SkyFlyoutHarness };
//# sourceMappingURL=skyux-flyout-testing.mjs.map
